@@ -117,7 +117,10 @@ def _repr(obj):
                 elif f.name == "<stdout>":
                     self.s = "stdout"
                 else:
-                    self.s = "file('%s','%s')" % (f.name, f.mode)
+                    if f.mode == "r":
+                        self.s = "file('%s')" % f.name
+                    else:
+                        self.s = "file('%s','%s')" % (f.name, f.mode)
             else:
                 self.s = repr(f)
 
@@ -182,8 +185,12 @@ argparse._SubParsersAction.add_parser = _add_parser
 class ConfArgParser(argparse.ArgumentParser):
     def __init__(self, *args, **kwargs):
         self.section = kwargs.get("section", "defaults")
+        self.callback = kwargs.get("callback", lambda opt: True)
+
         if "section" in kwargs:
             del kwargs["section"]
+        if "callback" in kwargs:
+            del kwargs["callback"]
 
         ckwargs = dict(kwargs)
         ckwargs["add_help"] = False
@@ -255,12 +262,12 @@ class ConfArgParser(argparse.ArgumentParser):
             dest = a.dest
 
             if warn and (section, name) in self.dest_mapping:
-                d, t = self.dest_mapping[(section, name)]
+                d = self.dest_mapping[(section, name)]
                 if d != dest:
                     raise ValueError(
                             "Changing destination of this config address!")
             if warn and dest in self.config_mapping:
-                s, n, t = self.config_mapping[dest]
+                s, n = self.config_mapping[dest]
                 if s != section or n != name:
                     raise ValueError(
                             "Changing config address of this destination!")
@@ -319,7 +326,11 @@ class ConfArgParser(argparse.ArgumentParser):
         if args.conf_file:
             config = ConfigParser.SafeConfigParser()
             config.read(args.conf_file)
-            config_options = self.config2dest(config)
+            while True:
+                config_options = self.config2dest(config)
+                namespace = argparse.Namespace(**config_options)
+                if self.callback(self, namespace):
+                    break
             self.set_defaults(**config_options)
         if args.export_conf_file:
             self.args2config(remaining_argv).write(args.export_conf_file)
@@ -337,3 +348,4 @@ class ConfArgParser(argparse.ArgumentParser):
         if not self._subparsers:
             args = self._parse_config(args)
         return argparse.ArgumentParser.parse_args(self, args, namespace)
+   
